IpcClientImpl

Struct IpcClientImpl 

pub struct IpcClientImpl<Crypto, Com, Ses>
where Crypto: CryptoProvider<Com, Ses>, Com: CommunicationBackend, Ses: SessionRepository<Crypto::Session>,
{ inner: Arc<IpcClientInner<Crypto, Com, Ses>>, }
An IPC client that handles communication between different components and clients. It uses a crypto provider to encrypt and decrypt messages, a communication backend to send and receive messages, and a session repository to persist sessions.

This is the concrete implementation of the IpcClient trait.

Fields

inner: Arc<IpcClientInner<Crypto, Com, Ses>>

Implementations

Source

impl<Crypto, Com, Ses> IpcClientImpl<Crypto, Com, Ses>
where Crypto: CryptoProvider<Com, Ses>, Com: CommunicationBackend, Ses: SessionRepository<Crypto::Session>,

pub fn new(crypto: Crypto, communication: Com, sessions: Ses) -> Self

Create a new IPC client with the provided crypto provider, communication backend, and session repository.