pub struct IpcClientSubscription {
pub(crate) receiver: Receiver<IncomingMessage>,
pub(crate) topic: Option<String>,
}Expand description
A subscription to receive messages over IPC. The subcription will start buffering messages after its creation and return them when receive() is called. Messages received before the subscription was created will not be returned.
Fields
receiver: Receiver<IncomingMessage>topic: Option<String>Implementations
Sourceimpl IpcClientSubscription
impl IpcClientSubscription
Sourcepub async fn receive(
&mut self,
cancellation_token: Option<CancellationToken>,
) -> Result<IncomingMessage, ReceiveError>
pub async fn receive( &mut self, cancellation_token: Option<CancellationToken>, ) -> Result<IncomingMessage, ReceiveError>
Receive a message, optionally filtering by topic.
Setting the cancellation_token to None will wait indefinitely.