pub struct IpcClientTypedSubscription<Payload: DeserializeOwned + PayloadTypeName>(IpcClientSubscription, PhantomData<Payload>);Expand description
A subscription to receive messages over IPC. The subcription will start buffering messages after its creation and return them when receive() is called. Messages received before the subscription was created will not be returned.
Tuple Fields
0: IpcClientSubscription1: PhantomData<Payload>Implementations
Sourceimpl<Payload> IpcClientTypedSubscription<Payload>where
Payload: DeserializeOwned + PayloadTypeName,
impl<Payload> IpcClientTypedSubscription<Payload>where
Payload: DeserializeOwned + PayloadTypeName,
pub(crate) fn new(subscription: IpcClientSubscription) -> Self
Sourcepub async fn receive(
&mut self,
cancellation_token: Option<CancellationToken>,
) -> Result<TypedIncomingMessage<Payload>, TypedReceiveError>
pub async fn receive( &mut self, cancellation_token: Option<CancellationToken>, ) -> Result<TypedIncomingMessage<Payload>, TypedReceiveError>
Receive a message.
Setting the cancellation_token to None will wait indefinitely.