pub struct NoiseCryptoProviderState {
state: PersistentTransportState,
}Expand description
Session state for the Noise crypto provider.
Fields
state: PersistentTransportStateTrait Implementations
Sourceimpl Clone for NoiseCryptoProviderState
impl Clone for NoiseCryptoProviderState
Sourcefn clone(&self) -> NoiseCryptoProviderState
fn clone(&self) -> NoiseCryptoProviderState
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NoiseCryptoProviderState
impl Debug for NoiseCryptoProviderState
Sourceimpl<'de> Deserialize<'de> for NoiseCryptoProviderState
impl<'de> Deserialize<'de> for NoiseCryptoProviderState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for NoiseCryptoProviderState
impl Serialize for NoiseCryptoProviderState
Sourceimpl SessionRepository<NoiseCryptoProviderState> for GenericSessionRepository
impl SessionRepository<NoiseCryptoProviderState> for GenericSessionRepository
Sourcetype RemoveError = String
type RemoveError = String
Error returned when a session could not be removed.
Sourceasync fn get(
&self,
endpoint: Endpoint,
) -> Result<Option<NoiseCryptoProviderState>, Self::GetError>
async fn get( &self, endpoint: Endpoint, ) -> Result<Option<NoiseCryptoProviderState>, Self::GetError>
Load the session for the given destination, if one exists.