pub struct IpcClientImpl<Crypto, Com, Ses>where
Crypto: CryptoProvider<Com, Ses>,
Com: CommunicationBackend,
Ses: SessionRepository<Crypto::Session>,{
inner: Arc<IpcClientInner<Crypto, Com, Ses>>,
}Expand description
An IPC client that handles communication between different components and clients. It uses a crypto provider to encrypt and decrypt messages, a communication backend to send and receive messages, and a session repository to persist sessions.
This is the concrete implementation of the IpcClient trait.
Fields
inner: Arc<IpcClientInner<Crypto, Com, Ses>>Implementations
Sourceimpl<Crypto, Com, Ses> IpcClientImpl<Crypto, Com, Ses>where
Crypto: CryptoProvider<Com, Ses>,
Com: CommunicationBackend,
Ses: SessionRepository<Crypto::Session>,
impl<Crypto, Com, Ses> IpcClientImpl<Crypto, Com, Ses>where
Crypto: CryptoProvider<Com, Ses>,
Com: CommunicationBackend,
Ses: SessionRepository<Crypto::Session>,