pub trait PayloadTypeName {
const PAYLOAD_TYPE_NAME: &'static str;
}Expand description
This trait is used to ensure that the payload type has a topic associated with it.
Required Associated Constants
Sourceconst PAYLOAD_TYPE_NAME: &'static str
const PAYLOAD_TYPE_NAME: &'static str
The topic name associated with this payload type, used for routing/dispatch.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.