pub type InMemorySessionRepository<Session> = RwLock<HashMap<Endpoint, Session>>;Expand description
An in-memory session repository implementation that stores sessions in a HashMap protected by
an RwLock. This is a simple implementation that can be used for testing or in scenarios where
persistence is not required.
Aliased Type
pub struct InMemorySessionRepository<Session> { /* private fields */ }